@@ -11,7 +11,6 @@
 #'
 #' model <- lm(mpg ~ wt, mtcars)
 #' acceptable_formula(model)
-#'
 #' @export
 acceptable_formula <- function(model) {
   UseMethod("acceptable_formula")
@@ -59,7 +58,7 @@ acceptable_lm <- function(model) {
 
   # Check for in-line formulas
   funs <- fun_calls(model$call)
-  funs <- funs[!(funs %in% c("~", "+", "-", "*", "(", ")", "::", "lm", "glm", "factor"))]
+  funs <- funs[!(funs %in% c("~", "+", "-", "*", "(", ")", "::", "lm", "glm", "factor", "stats"))]
   if (length(funs) > 0) {
     contains_offset <- any(funs == "offset")
     contains_other <- funs[funs != "offset"]
@@ -78,4 +77,4 @@ acceptable_lm <- function(model) {
       call. = FALSE
     )
   }
-}
\ No newline at end of file
+}
