@@ -3,17 +3,23 @@ library(dplyr)
 library(tidypredict)
 library(randomForest)
 library(dbplyr)
-library(tibble)
-
+knitr::opts_chunk$set(
+  collapse = TRUE,
+  comment = "#>"
+)
 set.seed(100)
 
 ## ------------------------------------------------------------------------
 library(dplyr)
-library(tibble)
+library(tidypredict)
+library(randomForest)
+library(dbplyr)
 
 flights_table <- nycflights13::flights %>%
-  mutate(current_score = 0) %>%
-  rowid_to_column("flight_id")
+  mutate(
+    current_score = 0, 
+    flight_id = row_number()
+    ) 
 
 ## ------------------------------------------------------------------------
 library(DBI)
